==> rustc-1.83_1.83.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.83.0-src/tests/ui/coverage-attr/name-value.rs <==
#![feature(coverage_attribute)]
//@ edition: 2021

// Demonstrates the diagnostics produced when using the syntax
// `#[coverage = "off"]`, which should not be allowed.
//
// The syntax is tested both in places that can have a coverage attribute,
// and in places that cannot have a coverage attribute, to demonstrate the
// interaction between multiple errors.

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
mod my_mod {}

mod my_mod_inner {
    #![coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
//~| ERROR attribute should be applied to a function definition or closure
struct MyStruct;

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
impl MyStruct {
    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR attribute should be applied to a function definition or closure
    const X: u32 = 7;
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
//~| ERROR attribute should be applied to a function definition or closure
trait MyTrait {
    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR attribute should be applied to a function definition or closure
    const X: u32;

    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR attribute should be applied to a function definition or closure
    type T;
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
impl MyTrait for MyStruct {
    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR attribute should be applied to a function definition or closure
    const X: u32 = 8;

    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR attribute should be applied to a function definition or closure
    type T = ();
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
fn main() {}

==> rustc-1.89_1.89.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.89.0-src/tests/ui/coverage-attr/name-value.rs <==
#![feature(coverage_attribute)]
//@ edition: 2021
//@ reference: attributes.coverage.syntax

// Demonstrates the diagnostics produced when using the syntax
// `#[coverage = "off"]`, which should not be allowed.
//
// The syntax is tested both in places that can have a coverage attribute,
// and in places that cannot have a coverage attribute, to demonstrate the
// interaction between multiple errors.

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
mod my_mod {}

mod my_mod_inner {
    #![coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
//~| ERROR [E0788]
struct MyStruct;

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
impl MyStruct {
    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR [E0788]
    const X: u32 = 7;
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
//~| ERROR [E0788]
trait MyTrait {
    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR [E0788]
    const X: u32;

    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR [E0788]
    type T;
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
impl MyTrait for MyStruct {
    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR [E0788]
    const X: u32 = 8;

    #[coverage = "off"]
    //~^ ERROR malformed `coverage` attribute input
    //~| ERROR [E0788]
    type T = ();
}

#[coverage = "off"]
//~^ ERROR malformed `coverage` attribute input
fn main() {}
